summaryrefslogtreecommitdiffstats
path: root/src/widgets/qtextedit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets/qtextedit.cpp')
-rw-r--r--src/widgets/qtextedit.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/widgets/qtextedit.cpp b/src/widgets/qtextedit.cpp
index 5910ef4c..9a5502c1 100644
--- a/src/widgets/qtextedit.cpp
+++ b/src/widgets/qtextedit.cpp
@@ -1451,8 +1451,8 @@ void TQTextEdit::keyPressEvent( TQKeyEvent *e )
}
TQString t = e->text();
#ifdef Q_WS_X11
- extern bool qt_hebrew_keyboard_hack;
- if ( qt_hebrew_keyboard_hack ) {
+ extern bool tqt_hebrew_keyboard_hack;
+ if ( tqt_hebrew_keyboard_hack ) {
// the X11 keyboard layout is broken and does not reverse
// braces correctly. This is a hack to get halfway correct
// behaviour
@@ -5069,7 +5069,7 @@ void TQTextEdit::updateStyles()
void TQTextEdit::setDocument( TQTextDocument *dc )
{
if ( dc == 0 ) {
- qWarning( "Q3TextEdit::setDocument() called with null Q3TextDocument pointer" );
+ tqWarning( "Q3TextEdit::setDocument() called with null Q3TextDocument pointer" );
return;
}
if ( dc == doc )
@@ -6452,7 +6452,7 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
cur = tag->prev;
if ( !cur ) {
#ifdef QT_CHECK_RANGE
- qWarning( "TQTextEdit::optimParseTags: no left-tag for '<%s>' in line %d.", tag->tag.ascii(), tag->line + 1 );
+ tqWarning( "TQTextEdit::optimParseTags: no left-tag for '<%s>' in line %d.", tag->tag.ascii(), tag->line + 1 );
#endif
return; // something is wrong - give up
}
@@ -6475,7 +6475,7 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
break;
} else if ( !cur->leftTag ) {
#ifdef QT_CHECK_RANGE
- qWarning( "TQTextEdit::optimParseTags: mismatching %s-tag for '<%s>' in line %d.", cur->tag[0] == '/' ? "left" : "right", cur->tag.ascii(), cur->line + 1 );
+ tqWarning( "TQTextEdit::optimParseTags: mismatching %s-tag for '<%s>' in line %d.", cur->tag[0] == '/' ? "left" : "right", cur->tag.ascii(), cur->line + 1 );
#endif
return; // something is amiss - give up
}
@@ -6956,9 +6956,9 @@ void TQTextEdit::optimDrawContents( TQPainter * p, int clipx, int clipy,
// useful debug info
//
// tag = d->od->tags;
-// qWarning("###");
+// tqWarning("###");
// while ( tag ) {
// qWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
// tag->parent, tag->leftTag, tag->tag.latin1(), tag->parent ? tag->parent->tag.latin1():"<none>",
// tag->bold, tag->italic, tag->underline );
// tag = tag->next;
@@ -6956,9 +6956,9 @@ void TQTextEdit::optimDrawContents( TQPainter * p, int clipx, int clipy,
// while ( tag ) {
-// qWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
+// tqWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
// tag->parent, tag->leftTag, tag->tag.latin1(), tag->parent ? tag->parent->tag.latin1():"<none>",
// tag->bold, tag->italic, tag->underline );